@@ -25,9 +25,18 @@ class SharedBackendConf(SharedBackendConfUtils):
     # Getters
     #
 
+    def isH2OReplEnabled(self):
+        return self._jconf.isH2OReplEnabled()
+
+    def cloudName(self):
+        return self._get_option(self._jconf.cloudName())
+
     def backendClusterMode(self):
         return self._jconf.backendClusterMode()
 
+    def isProgressBarEnabled(self):
+        return self._jconf.isProgressBarEnabled()
+
     def scalaIntDefaultNum(self):
         return self._jconf.scalaIntDefaultNum()
 
@@ -121,9 +130,6 @@ class SharedBackendConf(SharedBackendConfUtils):
     def flowProxyRequestMaxSize(self):
         return self._jconf.flowProxyRequestMaxSize()
 
-    def flowDir(self):
-        return self._get_option(self._jconf.flowDir())
-
     def flowProxyResponseMaxSize(self):
         return self._jconf.flowProxyResponseMaxSize()
 
@@ -133,6 +139,9 @@ class SharedBackendConf(SharedBackendConfUtils):
     def isInsecureXGBoostAllowed(self):
         return self._jconf.isInsecureXGBoostAllowed()
 
+    def flowDir(self):
+        return self._get_option(self._jconf.flowDir())
+
     def clientIp(self):
         return self._get_option(self._jconf.clientIp())
 
@@ -187,12 +196,6 @@ class SharedBackendConf(SharedBackendConfUtils):
     def restApiTimeout(self):
         return self._jconf.restApiTimeout()
 
-    def cloudName(self):
-        return self._get_option(self._jconf.cloudName())
-
-    def isH2OReplEnabled(self):
-        return self._jconf.isH2OReplEnabled()
-
     def nthreads(self):
         return self._jconf.nthreads()
 
@@ -225,6 +228,14 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setReplDisabled()
         return self
 
+    def setProgressBarEnabled(self):
+        self._jconf.setProgressBarEnabled()
+        return self
+
+    def setProgressBarDisabled(self):
+        self._jconf.setProgressBarDisabled()
+        return self
+
     def setDefaultNumReplSessions(self, value):
         self._jconf.setDefaultNumReplSessions(value)
         return self
@@ -357,14 +368,14 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setMaxParallelScalaCellJobs(value)
         return self
 
-    def setBasePort(self, value):
-        self._jconf.setBasePort(value)
-        return self
-
     def setInternalPortOffset(self, value):
         self._jconf.setInternalPortOffset(value)
         return self
 
+    def setBasePort(self, value):
+        self._jconf.setBasePort(value)
+        return self
+
     def setMojoDestroyTimeout(self, value):
         self._jconf.setMojoDestroyTimeout(value)
         return self
