@@ -34,6 +34,7 @@ class H2OKMeans(H2OKMeansParams, H2OUnsupervisedAlgorithm, H2OKMeansExtras):
                  columnsToCategorical=[],
                  keepBinaryModels=False,
                  withContributions=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -44,7 +45,6 @@ class H2OKMeans(H2OKMeansParams, H2OUnsupervisedAlgorithm, H2OKMeansExtras):
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
-                 withDetailedPredictionCol=True,
                  maxIterations=10,
                  standardize=True,
                  seed=-1,
