@@ -30,7 +30,9 @@ class H2OAutoMLClassifier(H2OAutoML):
                  leaderboardDataFrame=None,
                  blendingDataFrame=None,
                  columnsToCategorical=[],
+                 keepBinaryModels=False,
                  withContributions=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -42,9 +44,8 @@ class H2OAutoMLClassifier(H2OAutoML):
                  splitRatio=1.0,
                  monotoneConstraints={},
                  withStageResults=False,
-                 withDetailedPredictionCol=True,
                  projectName=None,
-                 nfolds=5,
+                 nfolds=-1,
                  balanceClasses=False,
                  classSamplingFactors=None,
                  maxAfterBalanceSize=5.0,
@@ -65,7 +66,7 @@ class H2OAutoMLClassifier(H2OAutoML):
                  stoppingTolerance=-1.0,
                  excludeAlgos=None,
                  includeAlgos=["GLM", "DRF", "GBM", "DeepLearning", "StackedEnsemble", "XGBoost"],
-                 exploitationRatio=0.0):
+                 exploitationRatio=-1.0):
         Initializer.load_sparkling_jar()
         super(H2OAutoML, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.classification.H2OAutoMLClassifier", self.uid)
