@@ -21,9 +21,10 @@ from ai.h2o.sparkling.ml.params.HasInitialBiases import HasInitialBiases
 from ai.h2o.sparkling.ml.params.HasInitialWeights import HasInitialWeights
 from ai.h2o.sparkling.ml.params.HasIgnoredCols import HasIgnoredCols
 from ai.h2o.sparkling.ml.params.HasDeprecatedVariableImportances import HasDeprecatedVariableImportances
+from ai.h2o.sparkling.ml.params.HasDeprecatedAutoencoder import HasDeprecatedAutoencoder
 
 
-class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols, HasDeprecatedVariableImportances, Params):
+class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols, HasDeprecatedVariableImportances, HasDeprecatedAutoencoder, Params):
 
     ##
     # Param definitions
@@ -244,12 +245,6 @@ class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols,
         """If enabled, override the final model with the best model found during training.""",
         H2OTypeConverters.toBoolean())
 
-    autoencoder = Param(
-        Params._dummy(),
-        "autoencoder",
-        """Auto-Encoder.""",
-        H2OTypeConverters.toBoolean())
-
     useAllFactorLevels = Param(
         Params._dummy(),
         "useAllFactorLevels",
@@ -619,9 +614,6 @@ class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols,
     def getOverwriteWithBestModel(self):
         return self.getOrDefault(self.overwriteWithBestModel)
 
-    def getAutoencoder(self):
-        return self.getOrDefault(self.autoencoder)
-
     def getUseAllFactorLevels(self):
         return self.getOrDefault(self.useAllFactorLevels)
 
@@ -862,9 +854,6 @@ class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols,
     def setOverwriteWithBestModel(self, value):
         return self._set(overwriteWithBestModel=value)
 
-    def setAutoencoder(self, value):
-        return self._set(autoencoder=value)
-
     def setUseAllFactorLevels(self, value):
         return self._set(useAllFactorLevels=value)
 
