@@ -17,6 +17,7 @@ class H2OAutoMLBaseMixin:
         :returns: A new H2OFrame of predictions.
 
         :examples:
+        
         >>> # Set up an H2OAutoML object
         >>> aml = H2OAutoML(max_runtime_secs=30)
         >>> # Launch an H2OAutoML run
@@ -75,6 +76,7 @@ class H2OAutoMLBaseMixin:
         :return: an H2O model
 
         :examples:
+        
         >>> # Set up an H2OAutoML object
         >>> aml = H2OAutoML(max_runtime_secs=30)
         >>> # Launch an AutoML run
@@ -98,6 +100,7 @@ class H2OAutoMLBaseMixin:
                  by the evaluation metric
 
         :examples:
+        
         >>> # Set up an H2OAutoML object
         >>> aml = H2OAutoML(max_runtime_secs=30)
         >>> # Launch an AutoML run
@@ -135,6 +138,7 @@ class H2OAutoMLBaseMixin:
         """
         Retrieve the leaderboard.
         Contrary to the default leaderboard attached to the instance, this one can return columns other than the metrics.
+
         :param extra_columns: a string or a list of string specifying which optional columns should be added to the leaderboard. Defaults to None.
             Currently supported extensions are:
             - 'ALL': adds all columns below.
@@ -142,7 +146,9 @@ class H2OAutoMLBaseMixin:
             - 'predict_time_per_row_ms`: column providing the average prediction time by the model for a single row.
             - 'algo': column providing the algorithm name for each model.
         :return: An H2OFrame representing the leaderboard.
+        
         :examples:
+        
         >>> aml = H2OAutoML(max_runtime_secs=30)
         >>> aml.train(y=y, training_frame=train)
         >>> lb_all = aml.get_leaderboard('ALL')
@@ -168,7 +174,9 @@ class H2OAutoMLBaseMixin:
                             - 'training_time_ms': column providing the training time of each model in milliseconds (doesn't include the training of cross validation models).
                             - 'predict_time_per_row_ms`: column providing the average prediction time by the model for a single row.
         :return: An H2OModel or None if no model of a given family is present
+        
         :examples:
+        
         >>> # Set up an H2OAutoML object
         >>> aml = H2OAutoML(max_runtime_secs=30)
         >>> # Launch an AutoML run
@@ -231,8 +239,7 @@ def _fetch_leaderboard(aml_id, extensions=None):
     else extensions)
     resp = h2o.api("GET /99/Leaderboards/%s" % aml_id, data=dict(extensions=extensions))
     dest_key = resp['project_name'].split('@', 1)[0]+"_custom_leaderboard"
-    lb = _fetch_table(resp['table'], key=dest_key, progress_bar=False)
-    return h2o.assign(lb[1:], dest_key)
+    return _fetch_table(resp['table'], key=dest_key, progress_bar=False)
 
 
 def _fetch_table(table, key=None, progress_bar=True):
@@ -242,13 +249,14 @@ def _fetch_table(table, key=None, progress_bar=True):
         ori_progress_state = H2OJob.__PROGRESS_BAR__
         H2OJob.__PROGRESS_BAR__ = progress_bar
         # Parse leaderboard H2OTwoDimTable & return as an H2OFrame
-        return h2o.H2OFrame(table.cell_values, destination_frame=key, column_names=table.col_header, column_types=table.col_types)
+        fr = h2o.H2OFrame(table.cell_values, destination_frame=key, column_names=table.col_header, column_types=table.col_types)
+        return h2o.assign(fr[1:], key) # removing index and reassign id to ensure persistence on backend
     finally:
         H2OJob.__PROGRESS_BAR__ = ori_progress_state
 
 
-def _fetch_state(aml_id, properties=None):
-    state_json = h2o.api("GET /99/AutoML/%s" % aml_id)
+def _fetch_state(aml_id, properties=None, verbosity=None):
+    state_json = h2o.api("GET /99/AutoML/%s" % aml_id, data=dict(verbosity=verbosity))
     project_name = state_json["project_name"]
     if project_name is None:
         raise H2OValueError("No AutoML instance with id {}.".format(aml_id))
@@ -265,12 +273,10 @@ def _fetch_state(aml_id, properties=None):
     leaderboard = None
     if should_fetch('leaderboard'):
         leaderboard = _fetch_table(state_json['leaderboard_table'], key=project_name+"_leaderboard", progress_bar=False)
-        leaderboard = h2o.assign(leaderboard[1:], project_name+"_leaderboard")  # removing index and reassign id to ensure persistence on backend
 
     event_log = None
     if should_fetch('event_log'):
         event_log = _fetch_table(state_json['event_log_table'], key=project_name+"_eventlog", progress_bar=False)
-        event_log = h2o.assign(event_log[1:], project_name+"_eventlog")  # removing index and reassign id to ensure persistence on backend
 
     return dict(
         project_name=project_name,
